@@ -8,10 +8,9 @@ configure and implement a workflow to operate on a signac_ data space.
 
 .. _signac: https://signac.io/
 """
-from . import environment, environments, errors, hooks, scheduling, testing
+from . import environment, environments, errors, hooks, scheduling
 from .aggregates import aggregator, get_aggregate_id
 from .environment import get_environment
-from .operations import cmd, directives, with_job
 from .project import FlowProject, IgnoreConditions, classlabel, label, staticlabel
 from .template import init
 
@@ -25,7 +24,6 @@ __all__ = [
     "errors",
     "hooks",
     "scheduling",
-    "testing",
     "aggregator",
     "get_aggregate_id",
     "get_environment",
