@@ -13,6 +13,7 @@ from collections.abc import Collection, Iterable, Mapping
 from hashlib import md5
 
 from .errors import FlowProjectDefinitionError
+from .util.misc import _deprecated_warning
 
 
 def _get_unique_function_id(func):
@@ -45,7 +46,7 @@ def _get_unique_function_id(func):
 
 
 class aggregator:
-    """Decorator for operation functions that operate on aggregates.
+    """Class for generating aggregates for use in operations.
 
     By default, if the ``aggregator_function`` is ``None``, an aggregate of all
     jobs will be created.
@@ -57,8 +58,7 @@ class aggregator:
 
     .. code-block:: python
 
-        @aggregator()
-        @FlowProject.operation
+        @FlowProject.operation(aggregator=aggregator())
         def foo(*jobs):
             print(len(jobs))
 
@@ -133,8 +133,7 @@ class aggregator:
 
         .. code-block:: python
 
-            @aggregator.groupsof(num=2)
-            @FlowProject.operation
+            @FlowProject.operation(aggregator=aggregator.groupsof(num=2))
             def foo(*jobs):
                 print(len(jobs))
 
@@ -198,8 +197,7 @@ class aggregator:
 
         .. code-block:: python
 
-            @aggregator.groupby(key="key", default=-1)
-            @FlowProject.operation
+            @FlowProject.operation(aggregator=aggregator.groupby(key="key", default=-1))
             def foo(*jobs):
                 print(len(jobs))
 
@@ -348,6 +346,12 @@ class aggregator:
             The function to decorate.
 
         """
+        _deprecated_warning(
+            deprecation="@aggregator(...)",
+            alternative="Use FlowProject.operation(aggregator=aggregator(...)) instead.",
+            deprecated_in="0.23.0",
+            removed_in="0.24.0",
+        )
         if not callable(func):
             raise FlowProjectDefinitionError(
                 "Invalid argument passed while calling the aggregate "
@@ -357,6 +361,11 @@ class aggregator:
             raise FlowProjectDefinitionError(
                 "The with_job option cannot be used with aggregation."
             )
+        current_agg = getattr(func, "_flow_aggregate", None)
+        if current_agg is not None and current_agg != aggregator.groupsof(1):
+            raise FlowProjectDefinitionError(
+                "Cannot specify aggregates in function and decorator."
+            )
         setattr(func, "_flow_aggregate", self)
         return func
 
@@ -645,11 +654,17 @@ class _AggregateStoresCursor(_AggregatesCursor):
 
     def __len__(self):
         # Return number of aggregates summed across all aggregate stores
-        return sum(len(aggregate_store) for aggregate_store in self._stores)
+        return len(
+            {id_ for aggregate_store in self._stores for id_ in aggregate_store.keys()}
+        )
 
     def __iter__(self):
+        existing_stores = set()
         for aggregate_store in self._stores:
-            yield from aggregate_store.values()
+            for agg_id, aggregate in aggregate_store.items():
+                if agg_id not in existing_stores:
+                    existing_stores.add(agg_id)
+                    yield aggregate
 
 
 class _JobAggregateCursor(_AggregatesCursor):
